/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","es-mx",{abort:"La carga ha sido abortada por el usuario.",doneOne:"El archivo ha sido cargado completamente.",doneMany:"%1 archivos cargados completamente.",uploadOne:"Cargando archivo ({percentage}%)...",uploadMany:"Cargando archivos, {current} de {max} listo ({percentage}%)..."});