/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","ja",{abort:"アップロードを中止しました。",doneOne:"ファイルのアップロードに成功しました。",doneMany:"%1個のファイルのアップロードに成功しました。",uploadOne:"ファイルのアップロード中 ({percentage}%)...",uploadMany:"{max} 個中 {current} 個のファイルをアップロードしました。 ({percentage}%)..."});