/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","es",{abort:"Carga abortada por el usuario.",doneOne:"Archivo cargado exitósamente.",doneMany:"%1 archivos exitósamente cargados.",uploadOne:"Cargando archivo ({percentage}%)...",uploadMany:"Cargando archivos, {current} de {max} hecho ({percentage}%)..."});