/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","ca",{loadError:"S'ha produït un error durant la lectura del fitxer.",networkError:"S'ha produït un error de xarxa durant la càrrega del fitxer.",httpError404:"S'ha produït un error HTTP durant la càrrega del fitxer (404: Fitxer no trobat).",httpError403:"S'ha produït un error HTTP durant la càrrega del fitxer (403: Permís denegat).",httpError:"S'ha produït un error HTTP durant la càrrega del fitxer (estat d'error: %1).",noUrlError:"La URL de càrrega no està definida.",
responseError:"Resposta incorrecte del servidor"});